@@ -1,11 +1,13 @@
 __author__ = 'Andrea De Marco <24erre@gmail.com>'
-__version__ = '1.1'
+__version__ = '2.1.0'
 __classifiers__ = [
     'Development Status :: 5 - Production/Stable',
     'Intended Audience :: Developers',
     'License :: OSI Approved :: Apache Software License',
     'Operating System :: OS Independent',
-    'Programming Language :: Python',
+    'Programming Language :: Python :: 2.6',
+    'Programming Language :: Python :: 2.7',
+    'Programming Language :: Python :: 3.3',
     'Topic :: Internet :: WWW/HTTP',
     'Topic :: Software Development :: Libraries',
 ]
@@ -60,7 +62,7 @@ def parse_args():
     except:
         pass
     yml = yml or {}
-    args.repo_token = yml.get('repo_token', '')
+    args.repo_token = yml.get('repo_token', os.environ.get('COVERALLS_REPO_TOKEN', ''))
     args.service_name = yml.get('service_name', 'travis-ci')
     args.service_job_id = os.environ.get('TRAVIS_JOB_ID', '')
     return args
@@ -81,5 +83,5 @@ def wear(args=None):
         git=gitrepo(args.base_dir),
         source_files=coverage.coveralls(args.base_dir),
     )
-    print response.text
+    print(response.text)
     return response
